@@ -10,11 +10,13 @@ class AsyncSeleniumMiddleware:
                  drivers_number: int,
                  proxies: tuple,
                  change_proxy_on_each_request: bool,
-                 install_adblock: bool):
+                 install_adblock: bool,
+                 anticaptcha_api_key: str):
         self.driver_pool = DriverPool(drivers_number,
                                       proxies=proxies,
                                       change_proxy_on_each_request=change_proxy_on_each_request,
-                                      install_adblock=install_adblock)
+                                      install_adblock=install_adblock,
+                                      anticaptcha_api_key=anticaptcha_api_key)
 
     @classmethod
     def from_crawler(cls, crawler: Crawler):
@@ -23,7 +25,7 @@ class AsyncSeleniumMiddleware:
         change_proxy_on_each_request = crawler.settings.get("SELENIUM_CHANGE_PROXY_ON_EACH_REQUEST", True)
         install_adblock = crawler.settings.get("SELENIUM_INSTALL_ADBLOCK", True)
         anticaptcha_api_key = crawler.settings.get("SELENIUM_ANTICAPTCHA_API_KEY", None)
-        middleware = cls(drivers_number, proxies, change_proxy_on_each_request, install_adblock)
+        middleware = cls(drivers_number, proxies, change_proxy_on_each_request, install_adblock, anticaptcha_api_key)
         crawler.signals.connect(middleware.spider_closed, signals.spider_closed)
         return middleware
 
